@@ -18,6 +18,7 @@ from alphastats.plots.DimensionalityReduction import DimensionalityReduction
 from alphastats.plots.VolcanoPlot import VolcanoPlot
 from alphastats.plots.IntensityPlot import IntensityPlot
 from alphastats.plots.ClusterMap import ClusterMap
+from alphastats.plots.SampleHistogram import SampleHistogram
 from alphastats.utils import ignore_warning, check_for_missing_values
 
 
@@ -290,6 +291,14 @@ class Plot:
         )
         return  clustermap.plot
 
+    def plot_samplehistograms(self):
+        """Plots the Denisty distribution of each sample
+
+        Returns:
+            plotly: Plotly Graph Object
+        """
+        return SampleHistogram(dataset=self).plot()
+
     @check_for_missing_values
     def plot_dendrogram(
         self, linkagefun=lambda x: scipy.cluster.hierarchy.linkage(x, "complete")
