@@ -1,7 +1,11 @@
 import streamlit as st
 import pandas as pd
 import io
-from alphastats.gui.utils.ui_helper import sidebar_info
+
+try:
+    from alphastats.gui.utils.ui_helper import sidebar_info
+except ModuleNotFoundError:
+    from utils.ui_helper import sidebar_info
 
 
 def display_plotly_figure(plot):
@@ -18,8 +22,8 @@ def save_plotly(plot, format):
     )
 
 
-@st.cache
-def convert_df(df):
+@st.cache_data
+def convert_df(df, user_session_id = st.session_state.user_session_id):
     return df.to_csv().encode("utf-8")
 
 
