@@ -18,6 +18,7 @@ from statsmodels.stats.multitest import multipletests
 import os
 from pathlib import Path
 
+# code taken from Isabel Bludau - multicova
 
 def get_std(x):
     """
@@ -309,7 +310,7 @@ def get_fdr_line(t_limit, s0, n_x, n_y, plot=False,
     s_df_neg = s_df.copy()
     s_df_neg.fc_s = -s_df_neg.fc_s
 
-    s_df = s_df.append(s_df_neg)
+    s_df = pd.concat([s_df, s_df_neg])
 
     if (plot):
         fig = px.scatter(x=s_df.fc_s,
@@ -469,7 +470,7 @@ def get_fdr_line_regression(t_limits, s0, X, plot = False,
         s_df_neg = s_df.copy()
         s_df_neg.fc_s = -s_df_neg.fc_s
 
-        s_df = s_df.append(s_df_neg)
+        s_df = pd.concat([s_df, s_df_neg])
 
         if (plot):
             fig = px.scatter(x=s_df.fc_s,
